.. image:: https://img.shields.io/pypi/v/yafowil.widget.select2.svg
    :target: https://pypi.python.org/pypi/yafowil.widget.select2
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/yafowil.widget.select2.svg
    :target: https://pypi.python.org/pypi/yafowil.widget.select2
    :alt: Number of PyPI downloads

.. image:: https://github.com/conestack/yafowil.widget.select2/actions/workflows/test_py.yaml/badge.svg
    :target: https://github.com/conestack/yafowil.widget.select2/actions/workflows/test_py.yaml
    :alt: Test yafowil.widget.select2 Python

.. image:: https://github.com/conestack/yafowil.widget.select2/actions/workflows/test_js.yaml/badge.svg
    :target: https://github.com/conestack/yafowil.widget.select2/actions/workflows/test_js.yaml
    :alt: Test yafowil.widget.select2 JS

This is a **selection** widget for
`YAFOWIL <http://pypi.python.org/pypi/yafowil>`_,
based on `Select2 <http://ivaynberg.github.com/select2/>`_

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#select2>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.select2/index.html>`_
- `Select2 <http://ivaynberg.github.com/select2/>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/conestack/yafowil.widget.select2>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Johannes Raggam

- Robert Niederreiter

- Georg Bernhard

- Lena Daxenbichler
